@@ -259,13 +259,14 @@ class MonthDataAvroHelper:
         """
         return self.get_keys_for_week(datetime.now())
 
-    def process_and_return_aggregation_for_month(self, time, avro_base64_str, aggregate=True):
+    def process_and_return_aggregation_for_month(self, time, avro_base64_str, aggregate=True, field="counter"):
         """
         Return data for month given by time (including today)
 
         :param datetime time: Time from where we need to calculate N days
         :param str avro_base64_str: Base64 data of month data
         :param aggregate if true add and return sum, otherwise array
+        :param field if passed perform aggregation on that field default value is counter
         :return: Array containing N items (N = days) OR aggregated sum if aggregate=true
         """
 
@@ -274,7 +275,7 @@ class MonthDataAvroHelper:
         result = []
         for day in days_to_add:
             try:
-                result.append(data["data"][day]["counter"])
+                result.append(data["data"][day][field])
             except KeyError as error:
                 pass
         if aggregate is False:
@@ -285,23 +286,25 @@ class MonthDataAvroHelper:
                 sum = sum + i
             return sum
 
-    def process_and_return_aggregation_for_this_month(self, avro_base64_str, aggregate=True):
+    def process_and_return_aggregation_for_this_month(self, avro_base64_str, aggregate=True, field="counter"):
         """
         Return data for this month (including today)
 
         :param str avro_base64_str: Base64 data of month data
         :param aggregate if true add and return sum, otherwise array
+        :param field if passed perform aggregation on that field default value is counter
         :return: Array containing N items (N = days) OR aggregated sum if aggregate=true
         """
-        return self.process_and_return_aggregation_for_month(datetime.now(), avro_base64_str, aggregate)
+        return self.process_and_return_aggregation_for_month(datetime.now(), avro_base64_str, aggregate, field)
 
-    def process_and_return_aggregation_for_week(self, time, avro_base64_str, aggregate=True):
+    def process_and_return_aggregation_for_week(self, time, avro_base64_str, aggregate=True, field="counter"):
         """
         Return data for week given by time (including today)
 
         :param datetime time: Time from where we need to calculate N days
         :param str avro_base64_str: Base64 data of month data
         :param aggregate if true add and return sum, otherwise array
+        :param field if passed perform aggregation on that field default value is counter
         :return: Array containing N items (N = days) OR aggregated sum if aggregate=true
         """
 
@@ -310,7 +313,7 @@ class MonthDataAvroHelper:
         result = []
         for day in days_to_add:
             try:
-                result.append(data["data"][day]["counter"])
+                result.append(data["data"][day][field])
             except KeyError as error:
                 pass
         if aggregate is False:
@@ -321,34 +324,171 @@ class MonthDataAvroHelper:
                 sum = sum + i
             return sum
 
-    def process_and_return_aggregation_for_this_week(self, avro_base64_str, aggregate=True):
+    def process_and_return_aggregation_for_this_week(self, avro_base64_str, aggregate=True, field="counter"):
         """
         Return data for this week (including today)
 
         :param str avro_base64_str: Base64 data of month data
         :param aggregate if true add and return sum, otherwise array
+        :param field if passed perform aggregation on that field default value is counter
         :return: Array containing N items (N = days) OR aggregated sum if aggregate=true
         """
-        return self.process_and_return_aggregation_for_week(datetime.now(), avro_base64_str, aggregate)
+        return self.process_and_return_aggregation_for_week(datetime.now(), avro_base64_str, aggregate, field)
 
-    def process_and_return_for_day(self, time, avro_base64_str):
+    def process_and_return_for_day(self, time, avro_base64_str, field="counter"):
         """
         Return data for day given by time (including today)
 
+        :param datetime time: Time from where we need to calculate for any day
         :param str avro_base64_str: Base64 data of month data
+        :param field if passed return data for that field default value is counter
         :return: return data for today
         """
         data = self.process(avro_base64_str)
         try:
-            return data["data"]["{}-{}".format(time.month, time.day)]["counter"]
+            return data["data"]["{}-{}".format(time.month, time.day)][field]
         except KeyError as error:
             return 0
 
-    def process_and_return_for_today(self, avro_base64_str):
+    def process_and_return_for_today(self, avro_base64_str, field="counter"):
         """
         Return data for day given by time (including today)
 
         :param str avro_base64_str: Base64 data of month data
+        :param field if passed return data for that field default value is counter
         :return: return data for today
         """
-        return self.process_and_return_for_day(datetime.now(), avro_base64_str)
+        return self.process_and_return_for_day(datetime.now(), avro_base64_str, field)
+
+    def process_and_return_string_data_for_month(self, time, avro_base64_str, aggregate=True, union=True, separator=";", field="str"):
+        """
+        Return data for month given by time (including today)
+
+        :param datetime time: Time from where we need to calculate N days
+        :param str avro_base64_str: Base64 data of month data
+        :param aggregate: if true add and return count, otherwise array
+        :param union: if true return union of the string data for days else intersection
+        :param separator: how to separate items in string data
+        :param field: if passed perform result on that field default value is str
+        :return: Array containing N items (N = days) OR count if aggregate=true
+        """
+
+        data = self.process(avro_base64_str)
+        days_to_add = self.get_keys_for_month(time)
+        list_days = []
+        for day in days_to_add:
+            try:
+                string_data = data["data"][day][field]
+                if isinstance(string_data, str):
+                    list_days.append(string_data.split(separator))
+            except KeyError as error:
+                pass
+        final_set = set()
+        for list_day in list_days:
+            if union:
+                final_set = final_set.union(set(list_day))
+            else:
+                final_set = final_set.intersection(set(list_day))
+
+        if aggregate:
+            return len(final_set)
+        else:
+            return list(final_set)
+
+    def process_and_return_string_data_for_this_month(self, avro_base64_str, aggregate=True, union=True, separator=";", field="str"):
+        """
+        Return data for this month (including today)
+
+        :param str avro_base64_str: Base64 data of month data
+        :param aggregate: if true add and return count, otherwise array
+        :param union: if true return union of the string data for days else intersection
+        :param separator: how to separate items in string data
+        :param field: if passed perform result on that field default value is str
+        :return: Array containing N items (N = days) OR count if aggregate=true
+        """
+        return self.process_and_return_aggregation_for_month(datetime.now(), avro_base64_str, aggregate, union, separator, field)
+
+    def process_and_return_string_data_for_week(self, time, avro_base64_str, aggregate=True, union=True, separator=";", field="str"):
+        """
+        Return data for week given by time (including today)
+
+        :param datetime time: Time from where we need to calculate N days
+        :param str avro_base64_str: Base64 data of month data
+        :param aggregate: if true add and return count, otherwise array
+        :param union: if true return union of the string data for days else intersection
+        :param separator: how to separate items in string data
+        :param field: if passed perform result on that field default value is str
+        :return: Array containing N items (N = days) OR count if aggregate=true
+        """
+
+        data = self.process(avro_base64_str)
+        days_to_add = self.get_keys_for_week(time)
+        list_days = []
+        for day in days_to_add:
+            try:
+                string_data = data["data"][day][field]
+                if isinstance(string_data, str):
+                    list_days.append(string_data.split(separator))
+            except KeyError as error:
+                pass
+        final_set = set()
+        for list_day in list_days:
+            if union:
+                final_set = final_set.union(set(list_day))
+            else:
+                final_set = final_set.intersection(set(list_day))
+
+        if aggregate:
+            return len(final_set)
+        else:
+            return list(final_set)
+
+    def process_and_return_string_data_for_this_week(self, avro_base64_str, aggregate=True, union=True, separator=";", field="str"):
+        """
+        Return data for this week (including today)
+
+        :param str avro_base64_str: Base64 data of month data
+        :param aggregate: if true add and return count, otherwise array
+        :param union: if true return union of the string data for days else intersection
+        :param separator: how to separate items in string data
+        :param field: if passed perform result on that field default value is str
+        :return: Array containing N items (N = days) OR count if aggregate=true
+        """
+        return self.process_and_return_aggregation_for_week(datetime.now(), avro_base64_str, aggregate, union, separator, field)
+
+    def process_and_return_string_data_for_day(self, time, avro_base64_str, aggregate=True, separator=";", field="str"):
+        """
+        Return data for day given by time (including today)
+
+        :param datetime time: Time from where we need to calculate for any day
+        :param str avro_base64_str: Base64 data of month data
+        :param aggregate: if true add and return count, otherwise array
+        :param separator: how to separate items in string data
+        :param field: if passed perform result on that field default value is str
+        :return: return data for today OR count if aggregate=true
+        """
+        data = self.process(avro_base64_str)
+        try:
+            result = data["data"]["{}-{}".format(time.month, time.day)][field]
+            result = set(result.split(separator))
+            if aggregate:
+                return len(result)
+            else:
+                return list(result)
+        except KeyError as error:
+            if aggregate:
+                return 0
+            else:
+                return []
+
+    def process_and_return_string_data_for_today(self, avro_base64_str, aggregate=True, separator=";", field="str"):
+        """
+        Return data for day given by time (including today)
+
+        :param str avro_base64_str: Base64 data of month data
+        :param aggregate: if true add and return count, otherwise array
+        :param separator: how to separate items in string data
+        :param field: if passed perform result on that field default value is str
+        :return: return data for today
+        """
+        return self.process_and_return_for_day(datetime.now(), avro_base64_str, aggregate, separator, field)
